/*
 * Ordermain.java -- test Cache Java
 *
 */

import java.io.*;
import java.util.*;
import java.text.*;
import com.lowagie.text.*;
import com.lowagie.text.pdf.*;
import com.intersys.objects.*;
import java.sql.*;

/**
 * This is a console program to test out Cache' Java
 *
 */
public class Ordermain {
    /**
     * The main entry point for the test program
     *
     * @param args Array of parameters passed to the application
     * via the command line.
     */
    public static void main( String[] args )
        throws Exception
    {
        Database         dbconnection = null;
        String           url="jdbc:Cache://localhost:1972/USER";
        String           username="_SYSTEM";  // null for default
        String           password="SYS";  // null for default
        Sample.Order          order = null;
        String stQuery = "SELECT DISTINCT TheOrder->ID AS OID FROM Sample.OrderItem WHERE TheProductStock->Color = ";
        Id              oid = null;
        NumberFormat nf = NumberFormat.getCurrencyInstance();

        boolean isQuick = false;
        for (int i = 0; i < args.length; i++)
            if (args[i].equals("-quick"))
                isQuick = true;
            else if (args[i].equals("-oid"))
                oid = new Id (args[++i]);

 	Class.forName ("com.intersys.jdbc.CacheDriver");

        Document document = new Document();

        try {
            /* Connect to this machine, in the TEST namespace */
            if (isQuick)
                dbconnection = CacheDatabase.getLightDatabase (url, username, password);
            else
                dbconnection = CacheDatabase.getDatabase (url, username, password);


            System.out.println( "Connected." );

            //Sample.Person.checkAllFieldsValid(dbconnection);
 	    Statement stmt = dbconnection.createStatement();
 	    InputStreamReader isr = new InputStreamReader(System.in);
 	    BufferedReader br = new BufferedReader(isr);
 	    System.out.print("F: ");
 	    String color = br.readLine();
            stQuery = stQuery + "'" + color + "'";
 	    java.sql.ResultSet rs = stmt.executeQuery(stQuery);

            /* Get an instance of the Sample.Order object */
 	    while (rs.next()) {
                oid = new Id( rs.getString(1) );
 	    }

             if (oid == null)
                 {
                     System.out.println ("No record is matched " +
                                         "in the database.");
                     dbconnection.close();
                     return;
                 }

            if (!(Sample.Order.exists (dbconnection, oid)))
                {
                    System.out.println ("There is no Order with id " +
                                        oid.toString() + " in the database.");
                    dbconnection.close();
                    return;
                }

            order = (Sample.Order) Sample.Order._open( dbconnection, oid );

            PdfWriter pdfwriter = PdfWriter.getInstance(document, new FileOutputStream("c:\OrderPrint.pdf"));

            document.open();
            BaseFont bf = BaseFont.createFont(
            "HeiseiKakuGo-W5", "UniJIS-UCS2-H",false);
            PdfContentByte pcb = pdfwriter.getDirectContent();
            pcb.setLineWidth(2f);
            pcb.moveTo(30,800);
            pcb.lineTo(565,800);
            pcb.stroke();

            pcb.beginText();
            pcb.setFontAndSize(bf, 18);
            pcb.setLeading(15);
            pcb.showTextAligned(PdfContentByte.ALIGN_CENTER,"׏",297,750,0);
            pcb.endText();

            pcb.beginText();
            pcb.setTextMatrix(1,0,0,1,100,700);
            pcb.setFontAndSize(bf, 10);
            pcb.setLeading(15);
            pcb.showText("ԍ ");
            pcb.showText(order.getId().toString());
            pcb.newlineShowText("");
            pcb.showText(order.getCustomer1().getAddress1().getZip());
            pcb.showText(" ");
            pcb.showText(order.getCustomer1().getAddress1().getPref());
            pcb.showText(order.getCustomer1().getAddress1().getCity());
            pcb.showText(order.getCustomer1().getAddress1().getStreet());
            pcb.newlineShowText("dbԍ ");
            pcb.showText(order.getCustomer1().getTelno());
            pcb.newlineShowText(order.getCustomer1().getName());
            pcb.showText(" 䒆");
            pcb.endText();

            PdfPTable table = new PdfPTable(5);
            int width[] = {50,10,10,10,15};
            table.setWidths(width);
            table.setWidthPercentage(100);
            table.getDefaultCell().setBorder(Rectangle.BOX);

            Font font = new Font(bf,12);
            PdfPCell cell;

            cell = new PdfPCell(new Phrase("i",font));
            cell.setHorizontalAlignment(Element.ALIGN_CENTER);
            table.addCell(cell);
            cell = new PdfPCell(new Phrase("TCY",font));
            cell.setHorizontalAlignment(Element.ALIGN_CENTER);
            table.addCell(cell);
            cell = new PdfPCell(new Phrase("F",font));
            cell.setHorizontalAlignment(Element.ALIGN_CENTER);
            table.addCell(cell);
            cell = new PdfPCell(new Phrase("",font));
            cell.setHorizontalAlignment(Element.ALIGN_CENTER);
            table.addCell(cell);
            cell = new PdfPCell(new Phrase("z",font));
            cell.setHorizontalAlignment(Element.ALIGN_CENTER);
            table.addCell(cell);

            Collection ci = order.getItems().values();
            Iterator oi = ci.iterator();
            while (oi.hasNext()) {
               Sample.OrderItem orderitem = (Sample.OrderItem) oi.next();
               cell = new PdfPCell(new Phrase(orderitem.getTheProductStock().getTheProductSize().getTheProduct().getName(),font));
               cell.setHorizontalAlignment(Element.ALIGN_CENTER);
               table.addCell(cell);
               cell = new PdfPCell(new Phrase(orderitem.getTheProductStock().getTheProductSize().getSSize(),font));
               cell.setHorizontalAlignment(Element.ALIGN_CENTER);
               table.addCell(cell);
               cell = new PdfPCell(new Phrase(orderitem.getTheProductStock().getColor(),font));
               cell.setHorizontalAlignment(Element.ALIGN_CENTER);
               table.addCell(cell);
               cell = new PdfPCell(new Phrase(orderitem.getQuantity().toString(),font));
               cell.setHorizontalAlignment(Element.ALIGN_RIGHT);
               table.addCell(cell);
               int amount;
               amount = orderitem.getTheProductStock().getTheProductSize().getPrice().intValue()  * orderitem.getQuantity().intValue();
               cell = new PdfPCell(new Phrase(nf.format(amount),font));
               cell.setHorizontalAlignment(Element.ALIGN_RIGHT);
               table.addCell(cell);
           }
           cell = new PdfPCell(new Phrase("v",font));
           cell.setColspan(4);
           cell.setHorizontalAlignment(Element.ALIGN_CENTER);
           table.addCell(cell);
           cell = new PdfPCell(new Phrase(nf.format(order.getTotal().intValue()),font));
           cell.setHorizontalAlignment(Element.ALIGN_RIGHT);
           table.addCell(cell);

           table.setTotalWidth(400);
           table.writeSelectedRows(0,-1,100,600,pdfwriter.getDirectContent());
           document.close();

            /* un-assign the objects */
            dbconnection.closeObject(order.getOref());
            order = null;
            /* Close the connection */
            dbconnection.close();
            System.out.println( "Disconnected." );

        } catch (CacheException ex) {
            System.out.println( "Caught exception0: " + ex.getClass().getName() + ": " + ex.getMessage() );
            ex.printFullTrace(System.out);
        } catch (Exception ex) {
            System.out.println( "Caught exception1: " + ex.getClass().getName() + ": " + ex.getMessage() );
            ex.printStackTrace();
        }
    }
}

/*
 * End-of-file
 *
 */

